slepc-3.18.0 2022-10-01
Report Typos and Errors

# RGSetOptionsPrefix

Sets the prefix used for searching for all RG options in the database.

### Synopsis

    #include "slepcrg.h"
    PetscErrorCode RGSetOptionsPrefix(RG rg,const char *prefix)

Logically Collective on rg

### Input Parameters

| rg | - the region context
| prefix | - the prefix string to prepend to all RG option requests

### Notes

A hyphen (-) must NOT be given at the beginning of the prefix name. The first character of all runtime options is AUTOMATICALLY the hyphen.

### See Also

RGAppendOptionsPrefix()

### Level

advanced

### Location

src/sys/classes/rg/rgbasic.c
Index of all RG routines
Table of Contents for all manual pages
Index of all manual pages